@@ -6,7 +6,11 @@ tryCatch(utils::globalVariables(c('.row')),
 #' \code{do()} provides a natural syntax for repetition tuned to assist 
 #' with replication and resampling methods.
 #'
+#' @rdname do
+#' @name do
 #' @param n  number of times to repeat 
+#' 
+#' @param object an object
 #'
 #' @param cull  function for culling output of objects being repeated.  If NULL,
 #'   a default culling function is used.  The default culling function is 
@@ -21,22 +25,23 @@ tryCatch(utils::globalVariables(c('.row')),
 #' @param mode  target mode for value returned
 #' 
 #' @param algorithm a number usd to select the algorithm used.  Currently numbers below 1 
-#' use an older algorithm and numbers >=1 use a newer algorithm which is faster in some 
-#' situations.
+#'   use an older algorithm and numbers >=1 use a newer algorithm which is faster in some 
+#'   situations.
 #' @param parallel a logical indicating whether parallel computation should be attempted
-#' using the \pkg{parallel} package (if it is installed).
+#'   using the \pkg{parallel} package (if it is installed).
 #' 
 #' @param e1 an object (in cases documented here, the result of running \code{do})
 #' @param e2 an object (in cases documented here, an expression to be repeated)
 #' 
+#' @note \code{do} is a thin wrapper around \code{Do} to avoid collision with
+#'   \code{\link[dplyr]{do}} from the \pkg{dplyr} package.
 #' @return \code{do} returns an object of class \code{repeater} which is only useful in
-#' the context of the operator \code{*}.  See the examples.
+#'   the context of the operator \code{*}.  See the examples.
 #' @author Daniel Kaplan (\email{kaplan@@macalaster.edu})
-#' and Randall Pruim (\email{rpruim@@calvin.edu})
+#'   and Randall Pruim (\email{rpruim@@calvin.edu})
 #'
 #' @seealso \code{\link{replicate}}
 #' 
-#' @export
 #' @examples
 #' do(3) * rnorm(1)
 #' do(3) * "hello"
@@ -46,11 +51,28 @@ tryCatch(utils::globalVariables(c('.row')),
 #' do(3) * mean(rnorm(25))
 #' do(3) * c(sample.mean = mean(rnorm(25)))
 #' do(3) * tally( ~sex|treat, data=resample(HELPrct))
-#' 
 #' @keywords iteration 
-#' 
+#' @export
 
-do <- function(n=1L, cull=NULL, mode='default', algorithm=1.0, parallel=TRUE) {
+do <- function(object, ...) {
+  UseMethod("do")
+}
+
+#' @rdname do
+#' @export
+do.numeric <- function(object, ...) {
+  Do(n=object, ...)
+}
+
+#' @rdname do
+#' @export
+do.default <- function(object, ...) {
+  dplyr::do(object, ...)
+}
+
+#' @rdname do
+#' @export
+Do <- function(n=1L, cull=NULL, mode='default', algorithm=1.0, parallel=TRUE) {
 	new( 'repeater', n=n, cull=cull, mode=mode, algorithm=algorithm, parallel=parallel)
 }
 
@@ -80,10 +102,9 @@ do <- function(n=1L, cull=NULL, mode='default', algorithm=1.0, parallel=TRUE) {
 #' @rdname nicenames
 #' @param x a character vector
 #' @return a character vector
-#' @export
 #' @examples
 #' nice_names( c("bad name", "name (crazy)", "a:b", "two-way") )
-
+#' @export
  
 nice_names <- function(x) {
 	x <- gsub('\\(Intercept\\)','Intercept', x)
@@ -106,7 +127,6 @@ nice_names <- function(x) {
 #'
 #' @rdname repeater-class
 #' @name repeater-class
-#' @exportClass repeater
 #' @seealso \code{\link{do}}
 #' @section Slots:
 #' \describe{
@@ -118,6 +138,7 @@ nice_names <- function(x) {
 #'   \item{\code{algorithm}:}{an algorithm number.}
 #'   \item{\code{parallel}:}{a logical indicating whether to attempt parallel execution.}
 #' }
+#' @exportClass repeater
 
 setClass('repeater', 
 	representation = representation(n='numeric', cull='ANY', mode='character', 
@@ -296,8 +317,7 @@ if(FALSE) {
 
 #' @rdname do
 #' @aliases print,repeater-method
-# @usage
-# \S4method{print}{repeater}(x, ...) 
+#' @export
 setMethod("print",
     signature(x = "repeater"),
     function (x, ...) 
@@ -349,8 +369,7 @@ setMethod("print",
 
 #' @rdname do
 #' @aliases *,repeater,ANY-method
-# @usage
-# \S4method{*}{repeater,ANY}(e1, e2) 
+#' @export
 
 setMethod("*",
     signature(e1 = "repeater", e2="ANY"),
@@ -358,7 +377,8 @@ setMethod("*",
     {
 		e2unevaluated = substitute(e2)
 		if ( ! is.function(e2) ) {
-			e2 = function(){eval.parent(e2unevaluated, n=1) }   
+      frame <- parent.frame()
+			e2 = function(){eval(e2unevaluated, envir=frame) }   
 		}
 		n = e1@n
 
