@@ -9,6 +9,7 @@
 #' a data frame with all logicals converted to factors in this manner.
 #'
 #' @rdname logical2factor
+#' @export
 
 logical2factor  <- function(x, ...) { UseMethod('logical2factor') }
 
@@ -21,6 +22,8 @@ logical2factor.default  <- function( x, ... ) {
 }
 
 #' @rdname logical2factor
+#' @export
+
 logical2factor.data.frame  <- function( x, ... ) {
 	for (var in names(x)) {
 		if (is.logical(x[,var])) {
@@ -48,8 +51,8 @@ logical2factor.data.frame  <- function( x, ... ) {
 #' @param quiet a logical indicating whether messages about order in which marginal distributions
 #'        are calculated should be surpressed.  See \code{\link{addmargins}}.
 #' @param margins a logical indicating whether marginal distributions should be displayed.
+#' @param useNA as in \code{\link{table}}, but the default here is \code{"ifany"}.
 #' @param ... additional arguments passed to \code{\link{table}}
-#' @export
 #' @examples
 #' tally( ~ substance, data=HELPrct)
 #' tally( ~ substance & sex , data=HELPrct)
@@ -58,13 +61,32 @@ logical2factor.data.frame  <- function( x, ... ) {
 #' tally( ~ substance | sex , data=HELPrct, format='count')
 #' tally( ~ substance & sex , data=HELPrct, format='percent')
 #' tally( ~ link, data=HELPrct, useNA="always")
+#' @export
 
+tally <- function(x, ...) {
+  UseMethod("tally")
+}
 
-tally <- function(x, data=parent.frame(), 
+#' @rdname tally
+#' @param wt for weighted tallying, 
+#'   see \code{\link[dplyr]{tally}} in \pkg{dplyr}
+#' @param sort a logical, 
+#'   see \code{\link[dplyr]{tally}} in \pkg{dplyr}
+#' @export
+
+tally.tbl <- function(x, wt, sort=FALSE, ...) {
+  dplyr::tally(x, wt, sort=sort)
+}
+
+#' @rdname tally
+#' @export
+
+tally.default <- function(x, data=parent.frame(), 
                       format=c('default','count','proportion','percent'), 
                       margins=FALSE,
                       quiet=TRUE,
-                      subset, ...) {
+                      subset, 
+                      useNA = "ifany", ...) {
 	format <- match.arg(format)
   if (! .is.formula(x) ) {
       formula <- ~ x
@@ -104,7 +126,7 @@ tally <- function(x, data=parent.frame(),
 		else format <- 'proportion'
 	}
 
-	res <- table( logical2factor( joinFrames(evalF$right,evalF$condition) ), ... )
+	res <- table( logical2factor( joinFrames(evalF$right,evalF$condition) ), useNA=useNA, ... )
 
 	res <- switch(format,
 		   'count' = 
@@ -133,6 +155,7 @@ tally <- function(x, data=parent.frame(),
 #' rows(HELPrct)
 #' columns(NULL)
 #' columns("this doesn't have columns")
+#' @export
 
 columns <- function(x, default=c()) {
 	hi <- ncol(x)
@@ -140,6 +163,8 @@ columns <- function(x, default=c()) {
 }
 
 #' @rdname columns
+#' @export
+
 rows <- function(x, default=c()) {
 	hi <- nrow(x)
 	if (is.null(hi) || hi < 1) return(default) else  return( 1:hi )
@@ -158,13 +183,13 @@ rows <- function(x, default=c()) {
 #' @param sep a character used to separate portions of long names
 #' @param format one of \code{proportion}, \code{percent}, or \code{count},
 #'        possibly abbrevaited
-#' @export
 #' @examples
 #' prop( ~sex, data=HELPrct)
 #' prop( ~sex, data=HELPrct, level='male')
 #' count( ~sex | substance, data=HELPrct)
 #' prop( ~sex | substance, data=HELPrct)
 #' perc( ~sex | substance, data=HELPrct)
+#' @export
 
 prop <- function(x, data=parent.frame(), ..., level=NULL, long.names=TRUE, sep=".", format="proportion") {
   T <- tally(x, data=data, ..., format=format)
@@ -187,11 +212,15 @@ prop <- function(x, data=parent.frame(), ..., level=NULL, long.names=TRUE, sep="
 }
 
 #' @rdname prop
+#' @export
+
 count <- function(x, data=parent.frame(), ..., format="count") {
 	prop(x, data=data, ..., format=format)
 }
 
 #' @rdname prop
+#' @export
+
 perc <- function(x, data=parent.frame(), ..., format="percent") {
 	prop(x, data=data, ..., format=format)
 }
