@@ -62,9 +62,11 @@ test_that("count/perc/prop wrappers work", {
 if(TRUE) { 
 test_that("... passes through to table()", {
 	x <- c(1,2,2,3,3,3,NA,NA)
-	expect_equivalent( length( tally(x) ), 3 )
-	expect_equivalent( length( tally(x, useNA='ifany') ), 4 )
-	expect_equivalent( length( tally(x, useNA='ifany', margins=TRUE) ), 5 )
-	expect_equivalent( length( tally(x[1:6], useNA='always') ), 4 )
+	expect_equivalent( length( tally(~x) ), 4  )
+	expect_equivalent( length(tally(~x, useNA='ifany') ), 4)
+	expect_equivalent( length(tally(~x, useNA='no') ), 3)
+	expect_equivalent( length(tally(~x[1:5], useNA='always') ), 4)
+	expect_equivalent( length(tally(~x, useNA='ifany', margins=TRUE) ), 5 )
+	expect_equivalent( length(tally(~x[1:6], useNA='always')), 4 )
 })
 }
